darkhistory.low_energy.lowE_electrons.compute_fs — DarkHistory documentation

# darkhistory.low_energy.lowE_electrons.compute_fs

`darkhistory.low_energy.lowE_electrons.` `compute_fs`(MEDEA_interp, spec_elec, xe, dE_dVdt_inj, dt)

  Given an electron energy spectrum, calculate how much of that energy splits into continuum photons, lyman_alpha transitions, H ionization, He ionization, and heating of the IGM.

  Parameters: | spec_elec : Spectrum object spectrum of low energy electrons. spec_elec.toteng() should return energy per baryon. xe : float The ionization fraction ne/nH. dE_dVdt_inj : float dE/dVdt, i.e. energy injection rate of DM per volume per time dt : float time in seconds over which these electrons were deposited.
  Returns: | list of floats Ratio of deposited energy to a given channel over energy deposited by DM. The order of the channels is heat, lyman, ionH, ionHe, cont

#### Previous topic

darkhistory.low_energy.lowE_electrons

#### Next topic

darkhistory.low_energy.lowE_electrons.make_interpolator

### This Page

Show Source